# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2010 Tiny SPRL (<http://tiny.be>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import fields,osv

class res_company(osv.osv):
    _name = 'res.company'
    _inherit = 'res.company'

    def _get_address_data(self, cr, uid, ids, field_names, arg, context=None):
        return super(res_company, self)._get_address_data(cr, uid, ids, field_names, arg, context=context)
    def _set_address_data(self, cr, uid, company_id, name, value, arg, context=None):
        return super(res_company, self)._set_address_data(cr, uid, company_id, name,value,arg, context=context)

    def onchange_postcode(self, cr, uid, ids, postcode, city, street):
        return self.pool.get('res.postcodes').onchange_postcode(cr,uid,ids,postcode,city,street)
    def onchange_street(self, cr, uid, ids, postcode, city, street):
        return self.pool.get('res.postcodes').onchange_street(cr,uid,ids,postcode,city,street)
    

    _columns = {
        'postcode': fields.function(_get_address_data, fnct_inv=_set_address_data, size=24, type='char', string="Postcode", multi='address'), 
    }
    
    
    def _get_sek(self, cr, uid, context=None):
        try:
            return self.pool.get('res.currency').search(cr, uid, [('currency','=','SEK')])[0]
        except:
            return False

    def _get_logo(self, cr, uid, ids):
        return open(os.path.join( tools.config['root_path'], 'addons', 'base', 'res', 'res_company_logo.png'), 'rb') .read().encode('base64')

    _header = """
<header>
<pageTemplate>
    <frame id="first" x1="28.0" y1="28.0" width="%s" height="%s"/>
    <pageGraphics>
        <fill color="black"/>
        <stroke color="black"/>
        <setFont name="DejaVu Sans" size="8"/>
        <drawString x="%s" y="%s"> [[ formatLang(time.strftime("%%Y-%%m-%%d"), date=True) ]]  [[ time.strftime("%%H:%%M") ]]</drawString>
        <setFont name="DejaVu Sans Bold" size="10"/>
        <drawCentredString x="%s" y="%s">[[ company.partner_id.name ]]</drawCentredString>
        <stroke color="#000000"/>
        <lines>%s</lines>
    </pageGraphics>
</pageTemplate>
</header>"""

    _header2 = _header % (539, 772, "1.0cm", "28.3cm", "11.1cm", "28.3cm", "1.0cm 28.1cm 20.1cm 28.1cm")

    _header3 = _header % (786, 525, 25, 555, 440, 555, "25 550 818 550")

    def _get_header(self,cr,uid,ids):
        try :
            header_file = tools.file_open(os.path.join('base', 'report', 'corporate_rml_header.rml'))
            try:
                return header_file.read()
            finally:
                header_file.close()
        except:
            return self._header_a4

    _header_main = """
    <header>
    <pageTemplate>
        <frame id="first" x1="1.3cm" y1="2.5cm" height="%s" width="19.0cm"/>
        <pageGraphics>
            <!-- You Logo - Change X,Y,Width and Height -->
            <image x="1.3cm" y="%s" height="40.0" >[[ company.logo or removeParentNode('image') ]]</image>
            <setFont name="DejaVu Sans" size="8"/>
            <fill color="gray"/>
            <stroke color="gray"/>
            <lines>1.3cm %s 20cm %s</lines>

            <drawRightString x="20cm" y="%s">[[ company.rml_header1 ]]</drawRightString>

            <drawString x="1.3cm" y="%s">[[ company.partner_id.name ]]</drawString>
            <drawString x="1.3cm" y="%s">[[ company.partner_id.address and company.partner_id.address[0].street or  '' ]]</drawString>
            <drawString x="1.3cm" y="%s">[[ company.partner_id.address and company.partner_id.address[0].postcode or '' ]] [[ company.partner_id.address and company.partner_id.address[0].city or '' ]]</drawString>
            <drawString x="1.3cm" y="%s">Tel:</drawString>
            <drawString x="2.6cm" y="%s">[[ company.partner_id.address and company.partner_id.address[0].phone or '' ]]</drawString>
            <drawString x="1.3cm" y="%s">E-post:</drawString>
            <drawString x="2.6cm" y="%s">[[ company.partner_id.address and company.partner_id.address[0].email or '' ]]</drawString>
            <lines>1.3cm %s 7cm %s</lines>

            <!--page bottom-->

            <lines>1.2cm 2.15cm 19.9cm 2.15cm</lines>

            <drawCentredString x="10.5cm" y="1.7cm">[[ company.rml_footer1 ]]</drawCentredString>
            <drawCentredString x="10.5cm" y="1.25cm">[[ company.rml_footer2 ]]</drawCentredString>
            <drawCentredString x="10.5cm" y="0.8cm">kontakt : [[ user.name ]] - sid: <pageNumber/></drawCentredString>
        </pageGraphics>
    </pageTemplate>
    </header>"""

    _header_a4 = _header_main % ('23.0cm', '27.6cm', '27.7cm', '27.7cm', '27.8cm', '27.2cm', '26.8cm', '26.4cm', '26.0cm', '26.0cm', '25.6cm', '25.6cm', '25.0cm', '25.0cm')
    _header_letter = _header_main % ('21.3cm', '25.9cm', '26.0cm', '26.0cm', '26.1cm', '25.5cm', '25.1cm', '24.7cm', '24.3cm', '24.3cm', '23.9cm', '23.9cm', '23.3cm', '23.3cm')

    def onchange_paper_format(self, cr, uid, ids, paper_format, context=None):
        if paper_format == 'us_letter':
            return {'value': {'rml_header': self._header_letter}}
        return {'value': {'rml_header': self._header_a4}}

    _defaults = {
        'currency_id': _get_sek,
        'paper_format': 'a4',
        'rml_header':_get_header,
        'rml_header2': _header2,
        'rml_header3': _header3,
        'logo':_get_logo
    }

    

res_company()



# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
